Learn R Programming

SMPracticals (version 1.3-1)

nematode: Nematode Data

Description

Numbers of nematodes invading individual fly larvae for various numbers of initial challengers.

Usage

data(nematode)

Arguments

source

Faddy, M. J. and Fenlon, J. S. (1999) Stochastic modelling of the invasion process of nematodes in fly larvae. Applied Statistics, 48, 31--37.

References

Davison, A. C. (2003) Statistical Models. Cambridge University Press. Page 295.

Examples

Run this code
data(nematode)

Run the code above in your browser using DataLab